import React from "react";
import PropTypes from "prop-types";
import styled from "styled-components";

export const Button = ({
  style,
  shape,
  prefix,
  suffix,
  label,
  onClick,
  props,
}) => {
  return (
    <StyledButton
      type="button"
      style={style}
      shape={shape}
      onClick={onClick}
      {...props}
    >
      <Icon src={prefix} loading="eager" />
      <Label>{label}</Label>
      <Icon src={suffix} loading="eager" />
    </StyledButton>
  );
};

const StyledButton = styled.button`
  background: ${(props) => props.theme.palette.primary.background};
  padding: 0.25em 1em;
  border: none;
  border-radius: ${({ shape }) => ShapeValues[shape].borderRadius};
  justify-content: center;
  display: flex;
`;

const Icon = styled.img`
  align-items: center;
  justify-content: center;
`;

const Label = styled.text`
  justify-self: center;
  margin: auto;
  color: ${(props) => props.theme.palette.primary.text};
  /* font-size: clamp(0.4em, 0.6em, 2em);  */
`;

Button.propTypes = {
  shape: PropTypes.oneOf(["Round", "Normal"]),
  prefix: PropTypes.string || PropTypes.element,
  suffix: PropTypes.string || PropTypes.element,
  label: PropTypes.string,
  onClick: PropTypes.func,
};

Button.defaultProps = {
  shape: "Normal",
  onClick: undefined,
  style: { height: "30px", width: "212px" },
};

const ShapeValues = {
  Round: {
    borderRadius: "50%",
  },
  Normal: {
    borderRadius: "10px",
  },
};
