import React, { useContext } from "react";
import PropTypes from "prop-types";
import { ThemeContext } from "styled-components";

export const SingleStep = ({
  activeColor,
  disableColor,
  ringSize,
  ringWidth,
  circleSize,
  lineLength,
  isActive,
  isLast,
}) => {
  const center = ringSize / 2 + ringWidth - 1;
  const radius = ringSize / 2;
  const { palette } = useContext(ThemeContext);
  const color = isActive
    ? activeColor || palette.highlight.background
    : disableColor || palette.secondary.background;
  
  return (
    <svg
      height={center + radius + 1 + (lineLength - 1) * !isLast}
      width={ringSize + ringWidth * 2}
    >
      <circle cx={center} cy={center} r={circleSize / 2} fill={color} />
      <circle
        cx={center}
        cy={center}
        r={radius}
        fillOpacity="0%"
        stroke={color}
        strokeWidth={ringWidth}
      />
      <line
        stroke={color}
        x1={center}
        y1={center + radius}
        x2={center}
        strokeWidth={ringWidth}
        y2={center + radius + lineLength}
        display={isLast ? "none" : "inline-box"}
      />
    </svg>
  );
};

SingleStep.propTypes = {
  activeColor: PropTypes.string,
  disableColor: PropTypes.string,
  ringSize: PropTypes.number,
  ringWidth: PropTypes.number,
  circleSize: PropTypes.number,
  lineLength: PropTypes.number,
  isActive: PropTypes.bool,
  isLast: PropTypes.bool,
};

SingleStep.defaultProps = {
  activeColor: null,
  disableColor: null,
  ringSize: 27,
  ringWidth: 2,
  circleSize: 15,
  lineLength: 60,
  isActive: true,
};
