import React, { useContext } from "react";
import PropTypes from "prop-types";
import styled from "styled-components";
import Moment from "react-moment";
import { SingleStep } from "./SingleStep";
import { ThemeContext } from "styled-components";

export const StepProgress = ({
  allSteps,
  userActions,
  textMarginTop,
  textMarginLeft,
}) => {
  const { palette } = useContext(ThemeContext);

  return (
    <StyledStepProgress>
      {allSteps.map((stap, index) => {
        const currentAction = userActions.find(
          (userAction) => userAction.type === stap.actionsType
        );
        const color = currentAction ? palette.highlight.background : palette.secondary.background;
        return (
          <StepInfo>
            <SingleStep
              isLast={allSteps.length - 1 === index}
              isActive={!!currentAction}
            />
            <Text
              color={color}
              textMarginTop={textMarginTop}
              textMarginLeft={textMarginLeft}
            >
              <Text>{stap.text}</Text>
              {currentAction && (
                <>
                  <Text>
                    <Moment format="DD/MM/YYYY">{currentAction.value}</Moment>
                  </Text>
                  <Text>
                    <Moment format="HH:mm:ss">{currentAction.value}</Moment>
                  </Text>
                </>
              )}
            </Text>
          </StepInfo>
        );
      })}
    </StyledStepProgress>
  );
};

const StepInfo = styled.div`
  display: flex;
`;

const StyledStepProgress = styled.div`
  display: flex;
  flex-direction: column;
`;

const Text = styled.div`
  margin: ${({ textMarginTop, textMarginLeft }) =>
    `${textMarginTop} ${textMarginLeft}`};
  color: ${({ color }) => color};
`;

StepProgress.propTypes = {
  allSteps: PropTypes.arrayOf(Object),

  userActions: PropTypes.arrayOf(Object),

  textMarginTop: PropTypes.string,

  textMarginLeft: PropTypes.string,
};

StepProgress.defaultProps = {
  allSteps: [],
  textMarginTop: "3px",
  textMarginLeft: "5px",
};
